@@ -26,7 +26,7 @@ from logging import getLogger
 from gi.repository import Gtk
 from gi.repository import Gdk
 
-from ..base.resources import Resources
+from ..resources import Resources
 from ..util import GladeInterface
 from ..tools import Tool, Job
 
@@ -34,7 +34,6 @@ from . import Preferences
 from .tools import ToolPreferences
 
 def _insert_column_with_attributes(view, pos, title, rend, **kwargs):
-    print kwargs
     tv = Gtk.TreeViewColumn(title)
     tv.pack_start(rend, True)
     for k in kwargs:
